@@ -1,11 +1,10 @@
 # -*- coding: utf-8 -*-
 
+import copy
 import os
 import re
-import copy
-from lxml import etree
 from decimal import Decimal
-
+from lxml import etree
 from simple_idml import IdPkgNS, BACKINGSTORY
 from simple_idml.utils import increment_xmltag_id, prefix_content_filename
 from simple_idml.utils import Proxy
@@ -267,6 +266,12 @@ class Spread(IDMLXMLFile):
     def get_node_name_from_xml_name(self):
         return rx_node_name_from_xml_name.match(self.name).groups()[0]
 
+    def set_layer_references(self, layer_id):
+        for elt in self.dom.iter():
+            if elt.get("ItemLayer"):
+                elt.set("ItemLayer", layer_id)
+        self.synchronize()
+
     def has_any_item_on_layer(self, layer_id):
         # The page Guide are not page items.
         return bool(len(self.node.xpath(".//*[not(self::Guide)][@ItemLayer='%s']" % layer_id)))
@@ -296,7 +301,7 @@ class Spread(IDMLXMLFile):
         textframe.set("PreviousTextFrame", "n")
         textframe.set("NextTextFrame", "n")
         # These attributes and subelements must be removed.
-        del textframe.attrib["StoryTitle"] # Suppose it is always present.
+        del textframe.attrib["StoryTitle"]  # Suppose it is always present.
         for sub_elt_name in ("InCopyExportOption", "FrameFittingOption", "ObjectExportOption"):
             try:
                 textframe.remove(textframe.find(sub_elt_name))
@@ -338,12 +343,14 @@ class Story(IDMLXMLFile):
        <XMLElement Self="%(xml_element_id)s" MarkupTag="XMLTag/%(xml_element_tag)s" XMLContent="%(story_id)s" />
      </Story>
 </idPkg:Story>
-""" % {"story_id": story_id,
-       "xml_element_tag": xml_element_tag,
-       "xml_element_id": xml_element_id})
+""" % {
+            "story_id": story_id,
+            "xml_element_tag": xml_element_tag,
+            "xml_element_id": xml_element_id
+        })
 
-        story.fobj.flush()
-        story.fobj.seek(0)
+        story.fobj.close()
+        story._fobj = None
         return story
 
     @property
@@ -362,7 +369,7 @@ class Story(IDMLXMLFile):
         element = self.get_element_by_id(element_id)
         try:
             self.get_element_content_nodes(element)[0].text = content
-        except IndexError as e:
+        except IndexError:
             pass
 
     def clear_element_content(self, element_id):
@@ -384,6 +391,7 @@ class Story(IDMLXMLFile):
     def get_element_content_and_xmlelement_nodes(self, element):
         return element.xpath(("./ParagraphStyleRange/CharacterStyleRange/Content | \
                                ./CharacterStyleRange/Content | \
+                               ./CharacterStyleRange/XMLElement | \
                                ./ParagraphStyleRange/XMLElement | \
                                ./XMLElement | \
                                ./Content"))
@@ -546,6 +554,20 @@ class Designmap(IDMLXMLFile):
         for layer in self.layer_nodes:
             layer.set("Name", "%s%s" % (layer.get("Name"), suffix))
 
+    def merge_layers(self, with_name=None):
+        layer_0 = self.layer_nodes.pop(0)
+        if with_name:
+            layer_0.set("Name", with_name)
+        for l in self.layer_nodes:
+            l.getparent().remove(l)
+        self._layer_nodes = None
+        self.active_layer = layer_0.get("Self")
+        self.synchronize()
+
+    def get_layer_id_by_name(self, layer_name):
+        layer_node = self.dom.xpath(".//Layer[@Name='%s']" % layer_name)[0]
+        return layer_node.get("Self")
+
 
 class Style(IDMLXMLFile):
     name = "Resources/Styles.xml"
@@ -558,7 +580,7 @@ class Style(IDMLXMLFile):
 
     def style_groups(self):
         """ Groups are `RootCharacterStyleGroup', `RootParagraphStyleGroup' etc. """
-        return [elt for elt in self.dom.xpath("/idPkg:Styles/*", namespaces={'idPkg':IdPkgNS})
+        return [elt for elt in self.dom.xpath("/idPkg:Styles/*", namespaces={'idPkg': IdPkgNS})
                 if re.match(r"^.+Group$", elt.tag)]
 
     def get_root(self):
