@@ -1,22 +1,19 @@
 # -*- coding: utf-8 -*-
 
+import copy
 import os
+import re
 import shutil
 import zipfile
-import re
-import copy
 from decimal import Decimal
-
 from lxml import etree
-
+from simple_idml import BACKINGSTORY, SETCONTENT_TAG, IGNORECONTENT_TAG, FORCECONTENT_TAG
 from simple_idml.components import get_idml_xml_file_by_name
 from simple_idml.components import (Designmap, Spread, Story, BackingStory,
                                     Style, StyleMapping, Graphic, Tags, Fonts, XMLElement)
 from simple_idml.decorators import use_working_copy
 from simple_idml.utils import increment_filename, prefix_content_filename, tree_to_etree_dom
 
-from simple_idml import BACKINGSTORY, SETCONTENT_TAG, IGNORECONTENT_TAG, FORCECONTENT_TAG
-
 STORIES_DIRNAME = "Stories"
 
 
@@ -58,13 +55,15 @@ class IDMLPackage(zipfile.ZipFile):
         if not self.working_copy_path:
             return zipfile.ZipFile.namelist(self)
         else:
-            trailing_slash_wc = "%s/" % self.working_copy_path
             namelist = []
             for root, dirs, filenames in os.walk(self.working_copy_path):
-                trailing_slash_root = "%s/" % root
-                rel_root = trailing_slash_root.replace(trailing_slash_wc, "")
+                rel_root = root.replace(self.working_copy_path, "")[1:]
                 for filename in filenames:
-                    namelist.append("%s%s" % (rel_root, filename))
+                    namelist.append("%(rel_root)s%(sep)s%(filename)s" % {
+                        'rel_root': rel_root,
+                        'sep': rel_root and "/" or "",
+                        'filename': filename
+                    })
             return namelist
 
     def contentfile_namelist(self):
@@ -561,7 +560,7 @@ class IDMLPackage(zipfile.ZipFile):
 
         try:
             node = self.xml_structure.xpath(under)[0]
-        except IndexError, err:
+        except IndexError:
             raise IndexError(u"Cannot remove content under path '%s'. Are you sure the path exists ?" % under)
         map(_remove_content, node.iterchildren())
         # `under' node may have a reference to its first children in his story.
@@ -626,7 +625,8 @@ class IDMLPackage(zipfile.ZipFile):
             self.style_mapping.synchronize()
 
         # Update designmap.xml because it may not reference the Mapping file.
-        if self.designmap.style_mapping_node is not None:
+        # if self Package does not have any style mapping.
+        if self.designmap.style_mapping_node is None:
             self.designmap.set_style_mapping_node()
             self.designmap.synchronize()
 
@@ -679,16 +679,32 @@ class IDMLPackage(zipfile.ZipFile):
         spread_dest = Spread(self, spread_dest_filename, self.working_copy_path)
         spread_dest_elt = spread_dest.dom.xpath("./Spread")[0]
 
-        for node in idml_package.xml_structure.xpath(only)[0].iter():
+        only_node = idml_package.xml_structure.xpath(only)[0]
+
+        # Add spread elements on the same layer. We start by that because the order in the
+        # Spread file is the z-position on the Layer.
+        only_layer = idml_package.get_structure_element_layer_id(only_node)
+        spread_elts_to_add = idml_package.get_spread_elements_by_layer(layer_id=only_layer,
+                                                                       excluded_tags=["Guide"])
+
+        # Then add the tagged elements that may be on others layers.
+        for node in only_node.iter():
             if node.get("XMLContent") is None:
                 continue
             spread_elt = idml_package.get_spread_elem_by_id(node.get("XMLContent"))
             # Image and EPS element are included in a Rectangle.
             if spread_elt.tag in ["Image", "EPS"]:
                 spread_elt = spread_elt.getparent()
+            if spread_elt not in spread_elts_to_add:
+                spread_elts_to_add.append(spread_elt)
+
+        def _add_spread_element(spread_dest_elt, spread_elt):
             spread_elt_copy = copy.deepcopy(spread_elt)
             self.apply_translation_to_element(spread_elt_copy, translation)
             spread_dest_elt.append(spread_elt_copy)
+
+        map(lambda s: _add_spread_element(spread_dest_elt, s), spread_elts_to_add)
+
         spread_dest.synchronize()
         self.init_lazy_references()
 
@@ -809,6 +825,17 @@ class IDMLPackage(zipfile.ZipFile):
         self.init_lazy_references()
         return self
 
+    @use_working_copy
+    def merge_layers(self, with_name=None):
+        # Remove all Layer in Designmap but the first.
+        self.designmap.merge_layers(with_name)
+        layer_id = self.designmap.active_layer
+
+        # Update ItemLayer in spread elements.
+        for spread_object in self.spreads_objects:
+            spread_object.set_layer_references(layer_id)
+        return self
+
     @use_working_copy
     def xml_element_leaf_to_node(self, xpath, xml_content_ref):
         spread = self.get_spread_object_by_xpath(xpath)
@@ -848,6 +875,18 @@ class IDMLPackage(zipfile.ZipFile):
         # The spread synchronization is done outside.
         return new_spread
 
+    def get_spread_elements_by_layer(self, layer_name=None, layer_id=None, excluded_tags=[]):
+        layer_id = layer_id or self.get_layer_id_by_name(layer_name)
+
+        spread_elements = []
+        for spread_object in self.spreads_objects:
+            spread_elements.extend(spread_object.dom.xpath(
+                ".//*%(excluded_tags)s[@ItemLayer='%(layer_id)s']" % {
+                    'excluded_tags': "".join(["[not(self::%s)]" % e for e in excluded_tags]),
+                    'layer_id': layer_id}))
+
+        return spread_elements
+
     def get_spread_object_by_xpath(self, xpath):
         elt_id = self.xml_structure.xpath(xpath)[0].get("XMLContent")
         return self.get_spread_object_by_id(elt_id)
@@ -890,6 +929,17 @@ class IDMLPackage(zipfile.ZipFile):
         spread = self.get_spread_object_by_xpath(xpath)
         return spread and spread.name or None
 
+    def get_layer_id_by_name(self, layer_name):
+        return self.designmap.get_layer_id_by_name(layer_name)
+
+    def get_structure_element_layer_id(self, xml_element):
+        spread_elt = self.get_spread_elem_by_id(xml_element.get("XMLContent"))
+        return self.get_spread_element_layer_id(spread_elt)
+
+    def get_spread_element_layer_id(self, spread_element):
+        return spread_element.get("ItemLayer") or \
+            self.get_spread_element_layer_id(spread_element.getparent())
+
     def get_story_object_by_xpath(self, xpath):
         xml_element = self.xml_structure.xpath(xpath)[0]
 
