@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 import copy
+import new
 import os
 import re
-import new
 from lxml import etree
 from types import MethodType
 
@@ -37,7 +37,12 @@ def increment_filename(filename):
 
         result = "%s%s" % (root_start, root_end)
 
-    return os.path.join(dirname, "%s%s" % (result, ext))
+    return "%(dirname)s%(sep)s%(root)s%(ext)s" % {
+        'dirname': dirname,
+        'sep': dirname and "/" or "",
+        'root': result,
+        'ext': ext
+    }
 
 
 def prefix_content_filename(filename, prefix, mode):
@@ -79,11 +84,11 @@ class Proxy(object):
 def tree_to_etree_dom(tree):
     """Convert a tree in a elementTree dom instance.
 
-    >>> tree = {
-    ...     "tag": "Root",
-    ...     "attrs": {...},
-    ...     "content": ["foo", {subtree}, "bar", ...]
-    ... }
+    tree = {
+        "tag": "Root",
+        "attrs": {...},
+        "content": ["foo", {subtree}, "bar", ...]
+    }
 
     """
 
