@@ -7,8 +7,9 @@ import shutil
 import unittest
 import zipfile
 from cStringIO import StringIO
-from urllib2 import OpenerDirector
+from simple_idml.indesign import indesign
 from suds.client import ServiceSelector
+from urllib2 import OpenerDirector
 
 CURRENT_DIR = os.path.dirname(__file__)
 IDMLFILES_DIR = os.path.join(CURRENT_DIR, "IDML")
@@ -43,28 +44,46 @@ class InDesignTestCase(unittest.TestCase):
         self.runscript_patcher.stop()
 
     def test_save_as(self):
-        from simple_idml.indesign import indesign
-
-        responses = indesign.save_as(os.path.join(IDMLFILES_DIR, "4-pages.idml"), ["indd"],
+        responses = indesign.save_as(os.path.join(IDMLFILES_DIR, "4-pages.idml"),
+                                     [{"fmt": "indd"}],
                                      "http://url-to-indesign-server:8080",
                                      CLIENT_WORKDIR, SERVER_WORKDIR,
                                      indesign_server_path_style="posix")
 
         self.assertTrue(self.runscript_mock.called)
-        self.assertEqual(responses, ['save_as.jsx, 4-pages.indd'])
+        self.assertEqual(responses, ['save_as.jsx, 4-pagesTMP.indd, {}'])
 
         responses = indesign.save_as(os.path.join(IDMLFILES_DIR, "4-pages.idml"),
-                                     ["pdf", "jpeg", "zip"],
+                                     [{"fmt": "pdf",
+                                       "params": {
+                                           "colorSpace": "CMYK",
+                                           "standartsCompliance": "1A2003",
+                                       }},
+                                      {"fmt": "jpeg"},
+                                      {"fmt": "zip"}],
                                      "http://url-to-indesign-server:8080",
                                      CLIENT_WORKDIR, SERVER_WORKDIR,
                                      indesign_server_path_style="posix")
         self.assertTrue(self.runscript_mock.called)
-        self.assertEqual(responses[:2], ['export.jsx, 4-pages.pdf',
-                                         'export.jsx, 4-pages.jpeg'])
+        self.assertEqual(responses[:2], [
+            "export.jsx, 4-pagesTMP.pdf, {'colorSpace': 'CMYK', 'standartsCompliance': '1A2003', 'format': 'pdf'}",
+            "export.jsx, 4-pagesTMP.jpeg, {'format': 'jpeg'}"
+        ])
         zip_buf = StringIO()
         zip_buf.write(responses[2])
         self.assertTrue(zipfile.is_zipfile(zip_buf))
 
+    def test_close_all_documents(self):
+        indesign.close_all_documents("http://url-to-indesign-server:8080",
+                                     CLIENT_WORKDIR, SERVER_WORKDIR,
+                                     indesign_server_path_style="posix")
+        self.assertTrue(self.runscript_mock.called)
+
+        indesign.close_all_documents("http://url-to-indesign-server:8080",
+                                     CLIENT_WORKDIR, SERVER_WORKDIR,
+                                     indesign_server_path_style="windows")
+        self.assertTrue(self.runscript_mock.called)
+
 
 class OpenerDirectorMock(OpenerDirector):
     def open(self, fullurl=None, data=None, timeout=None):
@@ -76,14 +95,22 @@ class OpenerDirectorMock(OpenerDirector):
 class ServiceSelectorMock(ServiceSelector):
     def RunScript(self, params):
         script = os.path.basename(params['scriptFile'])
-        dst = params['scriptArgs'][1]['value']
-        if script == 'package_to_print.jsx':
-            os.mkdir(dst)  # Create the destination dir.
-            dst = "%s.zip" % dst
+        script_args = dict([(p["name"], p["value"]) for p in params['scriptArgs']])
+        if script in indesign.JS_SAVE_AS_SCRIPTS:
+            script_args.pop("source")
+            dst_filename = script_args.pop("destination")
+            extra_params = script_args
+            if script == indesign.JS_PACKAGE_SCRIPT:
+                os.mkdir(dst_filename)  # Create the destination dir.
+                dst_filename = "%s.zip" % dst_filename
 
-        # Create the file in workdir and write something testable in it.
-        fobj = open(dst, "w+")
-        fobj.write("%s, %s" % (script, os.path.basename(dst)))
+            # Create the file in workdir and write something testable in it.
+            fobj = open(dst_filename, "w+")
+            fobj.write("%s, %s, %s" % (script,
+                                       os.path.basename(dst_filename),
+                                       extra_params))
+        elif script in indesign.JS_CLOSE_ALL_SCRIPT:
+            pass
 
 
 def suite():
